@@ -15,11 +15,15 @@ class ConnectionRefusedError(ConnectionError):
     """
     def __init__(self, *args):
         if len(args) == 0:
-            self.error_args = None
+            self.error_args = {'message': 'Connection rejected by server'}
         elif len(args) == 1:
-            self.error_args = args[0]
+            self.error_args = {'message': str(args[0])}
         else:
-            self.error_args = args
+            self.error_args = {'message': str(args[0])}
+            if len(args) == 2:
+                self.error_args['data'] = args[1]
+            else:
+                self.error_args['data'] = args[1:]
 
 
 class TimeoutError(SocketIOError):
